/**	
*	@file	ColourSchemeChooser.java
*	@author	Tim Connolly
*	@date	14/04/13
*	@see	GUI.java, Chart.java, ColourList.java, ColourGenerator.java	
*
*	@brief  Creates a interface for a user to select colour scheme
*
*	ColourSchemeChooser creates a tabbed pane, the first containing pre-defined
*	colour schemes, the second tab contains a colour picker, for the user to
*	select the colours
*/



import java.awt.event.ActionEvent;
import javax.swing.ImageIcon;
import java.awt.GridLayout;
import java.awt.Dimension;
import java.awt.Container;
import javax.swing.JButton;
import java.awt.event.ActionListener;
import javax.swing.JLabel;
import javax.swing.JTabbedPane;
import javax.swing.JOptionPane;



public class ColourSchemeChooser {
	private GUI m_Host;

	/**
	*	Construct the ColourSchemeChooser
	*
	*	@param host is the main instance of the GUI class, containing the
	*		   methods and variables
	*/	
	public ColourSchemeChooser(GUI host){
		m_Host = host;
	}		
	
	/**
	*	@return tabbedPane - returns the tabbed pane
	*/
	public JTabbedPane CreateInterface(){				
		JTabbedPane tabbedPane = new JTabbedPane();
		tabbedPane.add("Pre-defined", createColourStyleInterface());
		tabbedPane.add("User-defined", createUserStyleInterface());			
		return tabbedPane;	
	}
	
	/**
	*	creates the interface adding the different components to it
	*
	*	@return colourStyleInterface
	*/
	private Container createColourStyleInterface(){
		final Container colourStyleInterface;
		final Chart chart = m_Host.GetChart();
		
		colourStyleInterface = new Container();
		colourStyleInterface.setLayout(new GridLayout(4,4,50,0));
		

		JButton warmButton = new JButton(new ImageIcon("icons/warm.png"));
		warmButton.addActionListener(new ActionListener() { 
			public void actionPerformed(ActionEvent evt) {	
				m_Host.SetColourScheme(ColourGenerator.WARM); 					
				if (chart != null){
					chart.SetColour(new ColourList(chart.GetData().Width(), 
														ColourGenerator.WARM));
					m_Host.SetChartOnPanel(chart);
				}
				m_Host.closeColourDialog();	
			}
		});
		JLabel warmLabel = new JLabel("Warm");
		
		JButton coldButton = new JButton(new ImageIcon("icons/Cold.png"));
		coldButton.addActionListener(new ActionListener() { 
			public void actionPerformed(ActionEvent evt) {		
				m_Host.SetColourScheme(ColourGenerator.COLD);   
				if (chart != null){
					chart.SetColour(new ColourList(chart.GetData().Width(),
														ColourGenerator.COLD));
					m_Host.SetChartOnPanel(chart);
				}
				m_Host.closeColourDialog();					
			}
		});
		JLabel coldLabel = new JLabel("Cold");
		
		JButton randomButton = new JButton(new ImageIcon("icons/Random.png"));
		randomButton.addActionListener(new ActionListener() { 
			public void actionPerformed(ActionEvent evt) {		
				m_Host.SetColourScheme(ColourGenerator.RANDOM);    
				if (chart != null){
					chart.SetColour(new ColourList(chart.GetData().Width(),
													ColourGenerator.RANDOM));
					m_Host.SetChartOnPanel(chart);
				}
				m_Host.closeColourDialog();			
			}
		});
		JLabel RandomLabel = new JLabel("Random");
		
		JButton Greybutton = new JButton(new ImageIcon("icons/Greyscale.png"));
		Greybutton.addActionListener(new ActionListener() { 
			public void actionPerformed(ActionEvent evt) {		
				m_Host.SetColourScheme(ColourGenerator.GREYSCALE);
				if (chart != null){
					chart.SetColour(new ColourList(chart.GetData().Width(), 
													ColourGenerator.GREYSCALE));
					m_Host.SetChartOnPanel(chart);
				}
				m_Host.closeColourDialog();		
			}
		});
		JLabel greyLabel = new JLabel("Greyscale");
		
		JButton Highbutton = new JButton(new ImageIcon("icons/Highcontrast.png"));
		Highbutton.addActionListener(new ActionListener() { 
			public void actionPerformed(ActionEvent evt) {		
				m_Host.SetColourScheme(ColourGenerator.HCONTRAST);  
				if (chart != null){
					chart.SetColour(new ColourList(chart.GetData().Width(),
													ColourGenerator.HCONTRAST));
					m_Host.SetChartOnPanel(chart);
				}
				m_Host.closeColourDialog();					
			}
		});
		JLabel HighLabel = new JLabel("High Contrast");
		
		JButton Neonbutton = new JButton(new ImageIcon("icons/Neon.png"));
		Neonbutton.addActionListener(new ActionListener() { 
			public void actionPerformed(ActionEvent evt) {		
				m_Host.SetColourScheme(ColourGenerator.NEON);     
				if (chart != null){
					chart.SetColour(new ColourList(chart.GetData().Width(), 
														ColourGenerator.NEON));
					m_Host.SetChartOnPanel(chart);
				}
				m_Host.closeColourDialog();				
			}
		});
		JLabel NeonLabel = new JLabel("Neon");
		
		JButton BoClash = new JButton(new ImageIcon("icons/Boclash.png"));
		BoClash.addActionListener(new ActionListener() { 
			public void actionPerformed(ActionEvent evt) {		
				m_Host.SetColourScheme(ColourGenerator.BOCLASH);  
				if (chart != null){
					chart.SetColour(new ColourList(chart.GetData().Width(), 
													ColourGenerator.BOCLASH));
					m_Host.SetChartOnPanel(chart);
				}
				m_Host.closeColourDialog();					
			}
		});
		JLabel BoLabel = new JLabel("Blue & orange");
		
		JButton PyClash = new JButton(new ImageIcon("icons/Pyclash.png"));
		PyClash.addActionListener(new ActionListener() { 
			public void actionPerformed(ActionEvent evt) {		
				m_Host.SetColourScheme(ColourGenerator.PYCLASH); 
				if (chart != null){
					chart.SetColour(new ColourList(chart.GetData().Width(), 
													ColourGenerator.PYCLASH));
					m_Host.SetChartOnPanel(chart);
				}
				m_Host.closeColourDialog();				
			}
		});
		JLabel PyLabel = new JLabel("Purple & yellow");

		colourStyleInterface.add(warmButton);
		colourStyleInterface.add(coldButton);
		colourStyleInterface.add(randomButton);
		colourStyleInterface.add(Greybutton);
		colourStyleInterface.add(warmLabel); 
		colourStyleInterface.add(coldLabel);
		colourStyleInterface.add(RandomLabel); 
		colourStyleInterface.add(greyLabel);
		colourStyleInterface.add(Highbutton);
		colourStyleInterface.add(Neonbutton);
		colourStyleInterface.add(BoClash);
		colourStyleInterface.add(PyClash);
		colourStyleInterface.add(HighLabel); 
		colourStyleInterface.add(NeonLabel);
		colourStyleInterface.add(BoLabel); 
		colourStyleInterface.add(PyLabel);
		return colourStyleInterface;
	}
	
	/**
	*	@return colourPicker - returns a user selectable colour picker in
	*						   the tabbed pane on the second tab
	*/
	private Container createUserStyleInterface(){
		UserDefinedColourSelection colourPicker = new UserDefinedColourSelection(m_Host);				
		return colourPicker.CreateInterface();		
	}
}