/**
* @file UserDefinedColourSelection.java
* @author Alex Gurr
* @date 12 Apr 2013
* @see GUI
*
* @brief This is a Class that provides the user with an interface to create their own selection 
* of colours. They can choose the colours they want to make their own custom colour scheme.
*/



import java.awt.GridLayout;
import java.awt.BorderLayout;
import javax.swing.JColorChooser;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JLabel;
import javax.swing.JButton;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;	
import javax.swing.colorchooser.ColorSelectionModel;
import java.awt.Color;
import javax.swing.JOptionPane;
import javax.swing.JScrollPane;
import javax.swing.ScrollPaneConstants;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.awt.Dimension;




public class UserDefinedColourSelection extends JFrame {

	private Boolean m_colourPickBool = false;
	private Boolean m_colourAddBool = false;
	private Boolean testBool = false;
	private GUI m_Host;

	/**
	* Allows the class to reference the correct instance of the main GUI
	* @param host - instance of the main GUI 
	*/

	public UserDefinedColourSelection(GUI host){
		m_Host = host;
	}
	
	/**
	* Creates the main interface for the user and populates an arraylist of
	* user definedcolours for the colour scheme
	* 
	*/

	public JPanel CreateInterface(){
		final Chart chart = m_Host.GetChart();
		final JPanel panel = new JPanel(new BorderLayout());		
		final JColorChooser colorChooser = new JColorChooser();
		final JPanel previewColour = new JPanel();
		final ArrayList<Color> colourList = new ArrayList<Color>();
		final JScrollPane scrollPane = new JScrollPane();
		final JPanel subPanel = new JPanel(new GridLayout(2,2,80,20));

		if (testBool) {
			colourList.add(Color.red);
            colourList.add(Color.blue);
            colourList.add(Color.green);
            System.out.println("Added red, green and blue colours to array. " + 
            	"Scheme should contain minimum of these.");
		}

		JButton addColour = new JButton("Add to list");
		JButton okButton = new JButton("Apply");
		
		colorChooser.setPreviewPanel(new JPanel());	
		
		previewColour.setPreferredSize(new Dimension(30, 30));	
		
		panel.add(colorChooser, BorderLayout.PAGE_START);
		subPanel.add(new JLabel("Currently selected colour:"));
		subPanel.add(previewColour);
		subPanel.add(addColour);
		subPanel.add(okButton);
		panel.add(subPanel, BorderLayout.CENTER);

		final JPanel scrollPanePanel = new JPanel();
		scrollPane.setPreferredSize(new Dimension(300, 70));		
		scrollPanePanel.add(scrollPane);
		
	    colorChooser.getSelectionModel().addChangeListener(new ChangeListener() {
	      public void stateChanged(ChangeEvent e) {
	        previewColour.setBackground(colorChooser.getColor());
			m_colourPickBool = true;
	      }
	    });
			
		addColour.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {

            	if (m_colourPickBool == true) {
            		colourList.add(previewColour.getBackground());	

            		if (testBool) {
            			System.out.println("Colour added: " + 
            				previewColour.getBackground());
            		}

            		JPanel allColours = new JPanel();

            		for (int i = 0; i < colourList.size(); i++) {
						JPanel selectedCo = new JPanel();
						selectedCo.setPreferredSize(new Dimension(30,30));
						selectedCo.setBackground(colourList.get(i));
						allColours.add(selectedCo);
					}

               		scrollPane.getViewport().add(allColours);
               		scrollPanePanel.updateUI();
					m_colourAddBool = true;
            	} else {
            		JOptionPane.showMessageDialog(null, "Please select a colour" +
            		 "before adding one to the list");
            	}
            	
            }
       	}); 

       	okButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				if (m_colourAddBool == false){
					JOptionPane.showMessageDialog(null, "Please add at least 1 colour");
				} else {
					m_Host.SetUserColourScheme(colourList);
					m_Host.SetColourScheme(ColourGenerator.USER); 
					if (chart != null){
						chart.SetColour(new ColourList(colourList));
					}
					m_Host.closeColourDialog();
				}
       		}
       	});	 
		
       	panel.add(scrollPanePanel, BorderLayout.PAGE_END);
		return panel;
	}

	public static void main(String args[]){

	}
}