/**	
*	@file	Visualisation.java
*	@author	Jason Enderby
*	@date	06 Apr 2013
*	@see	ColourList, ChartData, ColourGenerator
*	
*	@brief Visual element to be displayed in JSwing
*	
*	Provides an interface for designing and displaying visual elements in a 
*	JSwing enviroment. Storing internal data and providing visual functions.
*	
*/



import	javax.swing.JPanel;



public class Visualisation extends JPanel{
	protected ColourList	m_ColourScheme;
	protected ChartData		m_Data;
	protected String		m_Title;
	
	/**
	*	Mutator for m_ColourScheme - the colour scheme of the chart. 
	*
	*	@param colour - new colour scheme to be applied
	*
	*	@return - success
	*/
	public boolean SetColour(ColourList colour) {
		boolean	success = false;
		if (colour != null) {
			m_ColourScheme = colour;
			success = true;
		}
		return success;
	};
	
	/**
	*	Accessor for m_Data
	*
	*	@return - the internal data
	*/
	public ChartData GetData(){
		return m_Data;
	}
	
	/**
	*	Mutator for m_Data - the internal data structure
	*
	*	@param data - data to be plotted
	*
	*	@return - success
	*/
	public boolean SetData(ChartData data) {
		boolean	success = false;
		if (data != null) {
			m_Data = data;
			success = true;
		}
		return success;
	};
	
	/**
	*	Accessor for m_Colour
	*
	*	@return - colour data
	*/
	public ColourList GetColour(){
		return m_ColourScheme;
	}

	/**
	*	Mutator for m_Title - title of visualisation
	*
	*	@param title - new title of visualisation
	*
	*	@return - success
	*/	
	public boolean SetTitle(String title){
		boolean	success = false;
		if (title != null) {
			m_Title = title;
			success = true;
		}
		return success;
	}
	
	/**
	*	Accessor for m_Title
	*
	*	@return - chart title
	*/
	public String GetTitle(){
		return m_Title;
	}
	
	/**
	*	Displays data in the form of a string
	*	@return - string representation of Visualisation
	*/
	public String toString() {
		return String.format("%s:\n%s\n%s\n",
			GetTitle(), GetData(), GetColour());
	}
	
	/**
	*	Unit test
	*	@param args - command line arguments (not used).
	*/
	public static void main(String[] args) {
		final int			TEST_COL_COUNT = 9;
		final String[][]	TEST_DATA = {{"5", "14", "3"}, 
			{"43", "1", "4"}, {"15", "28", "14"}};
		final String[]		TEST_COLUMNS = {"Test", "Data", "Yeah"};
		Visualisation	myVis = new Visualisation();
		myVis.SetColour(new ColourList(TEST_COL_COUNT,ColourGenerator.WARM));
		myVis.SetTitle("Jam");
		myVis.SetData(new ChartData(TEST_COLUMNS, TEST_DATA));
		System.out.printf("%s", myVis);
	}
}